@@ -1,45 +1,54 @@
-from __future__ import annotations
-
 import ast
-import asyncio
-from typing import TYPE_CHECKING, Any, Awaitable, Callable, List, Optional, Type, cast
+from typing import TYPE_CHECKING, Any, Callable, List, Optional, Type, cast
 
+from robot.parsing.lexer.tokens import Token
+
+from robotcode.core.concurrent import check_current_task_canceled
+from robotcode.core.language import language_id
 from robotcode.core.lsp.types import InlayHint, InlayHintKind, Range
+from robotcode.core.text_document import TextDocument
 from robotcode.core.utils.logging import LoggingDescriptor
+from robotcode.robot.diagnostics.library_doc import (
+    KeywordArgumentKind,
+    KeywordDoc,
+    LibraryDoc,
+)
+from robotcode.robot.diagnostics.namespace import Namespace
+from robotcode.robot.utils.ast import (
+    iter_nodes,
+    range_from_node,
+    range_from_token,
+)
 
-from ...common.decorators import language_id
-from ...common.text_document import TextDocument
 from ..configuration import InlayHintsConfig
-from ..diagnostics.library_doc import KeywordArgumentKind, KeywordDoc, LibraryDoc
-from ..diagnostics.namespace import Namespace
-from ..utils.ast_utils import Token, range_from_node, range_from_token
-from ..utils.async_ast import iter_nodes
 
 if TYPE_CHECKING:
     from ..protocol import RobotLanguageServerProtocol
 
-from ..diagnostics.model_helper import ModelHelperMixin
+from robotcode.robot.diagnostics.model_helper import ModelHelper
+
 from .protocol_part import RobotLanguageServerProtocolPart
 
 _HandlerMethod = Callable[
-    [TextDocument, Range, ast.AST, ast.AST, Namespace, InlayHintsConfig], Awaitable[Optional[List[InlayHint]]]
+    [TextDocument, Range, ast.AST, ast.AST, Namespace, InlayHintsConfig],
+    Optional[List[InlayHint]],
 ]
 
 
-class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
+class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
     _logger = LoggingDescriptor()
 
-    def __init__(self, parent: RobotLanguageServerProtocol) -> None:
+    def __init__(self, parent: "RobotLanguageServerProtocol") -> None:
         super().__init__(parent)
 
         parent.inlay_hint.collect.add(self.collect)
 
-    async def get_config(self, document: TextDocument) -> Optional[InlayHintsConfig]:
+    def get_config(self, document: TextDocument) -> Optional[InlayHintsConfig]:
         folder = self.parent.workspace.get_workspace_folder(document.uri)
         if folder is None:
             return None
 
-        return await self.parent.workspace.get_configuration_async(InlayHintsConfig, folder.uri)
+        return self.parent.workspace.get_configuration(InlayHintsConfig, folder.uri)
 
     def _find_method(self, cls: Type[Any]) -> Optional[_HandlerMethod]:
         if cls is ast.AST:
@@ -58,17 +67,19 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
 
     @language_id("robotframework")
     @_logger.call
-    async def collect(self, sender: Any, document: TextDocument, range: Range) -> Optional[List[InlayHint]]:
-        config = await self.get_config(document)
+    def collect(self, sender: Any, document: TextDocument, range: Range) -> Optional[List[InlayHint]]:
+        config = self.get_config(document)
         if config is None or not config.parameter_names and not config.namespaces:
             return None
 
-        model = await self.parent.documents_cache.get_model(document, False)
-        namespace = await self.parent.documents_cache.get_namespace(document)
+        model = self.parent.documents_cache.get_model(document, False)
+        namespace = self.parent.documents_cache.get_namespace(document)
 
         result: List[InlayHint] = []
 
-        async for node in iter_nodes(model):
+        for node in iter_nodes(model):
+            check_current_task_canceled()
+
             node_range = range_from_node(node)
             if node_range.end < range.start:
                 continue
@@ -78,20 +89,20 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
 
             method = self._find_method(type(node))
             if method is not None:
-                r = await method(document, range, node, model, namespace, config)
+                r = method(document, range, node, model, namespace, config)
                 if r is not None:
                     result.extend(r)
 
         return result
 
-    async def _handle_keywordcall_fixture_template(
+    def _handle_keywordcall_fixture_template(
         self,
         keyword_token: Token,
         arguments: List[Token],
         namespace: Namespace,
         config: InlayHintsConfig,
     ) -> Optional[List[InlayHint]]:
-        kw_result = await self.get_keyworddoc_and_token_from_position(
+        kw_result = self.get_keyworddoc_and_token_from_position(
             keyword_token.value,
             keyword_token,
             arguments,
@@ -107,9 +118,9 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
         if kw_doc is None:
             return None
 
-        return await self._get_inlay_hint(keyword_token, kw_doc, arguments, namespace, config)
+        return self._get_inlay_hint(keyword_token, kw_doc, arguments, namespace, config)
 
-    async def _get_inlay_hint(
+    def _get_inlay_hint(
         self,
         keyword_token: Optional[Token],
         kw_doc: KeywordDoc,
@@ -156,9 +167,7 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
                         continue
 
                     arg = kw_arguments[index]
-                    if i >= len(kw_arguments) and arg.kind not in [
-                        KeywordArgumentKind.VAR_POSITIONAL,
-                    ]:
+                    if i >= len(kw_arguments) and arg.kind != KeywordArgumentKind.VAR_POSITIONAL:
                         break
 
                     prefix = ""
@@ -168,17 +177,24 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
                         prefix = "**"
 
                     result.append(
-                        InlayHint(range_from_token(arguments[i]).start, f"{prefix}{arg.name}=", InlayHintKind.PARAMETER)
+                        InlayHint(
+                            range_from_token(arguments[i]).start,
+                            f"{prefix}{arg.name}=",
+                            InlayHintKind.PARAMETER,
+                        )
                     )
 
         if keyword_token is not None and config.namespaces:
-            lib_entry, kw_namespace = await self.get_namespace_info_from_keyword_token(namespace, keyword_token)
+            (
+                lib_entry,
+                kw_namespace,
+            ) = self.get_namespace_info_from_keyword_token(namespace, keyword_token)
             if lib_entry is None and kw_namespace is None:
                 if kw_doc.libtype == "LIBRARY":
                     lib = next(
                         (
                             lib
-                            for lib in (await namespace.get_libraries()).values()
+                            for lib in (namespace.get_libraries()).values()
                             if lib.name == kw_doc.libname and kw_doc in lib.library_doc.keywords.keywords
                         ),
                         None,
@@ -187,17 +203,22 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
                     lib = next(
                         (
                             lib
-                            for lib in (await namespace.get_resources()).values()
+                            for lib in (namespace.get_resources()).values()
                             if lib.name == kw_doc.libname and kw_doc in lib.library_doc.keywords.keywords
                         ),
                         None,
                     )
                 if lib is not None:
-                    result.append(InlayHint(range_from_token(keyword_token).start, f"{lib.alias or lib.name}."))
+                    result.append(
+                        InlayHint(
+                            range_from_token(keyword_token).start,
+                            f"{lib.alias or lib.name}.",
+                        )
+                    )
 
         return result
 
-    async def handle_KeywordCall(  # noqa: N802
+    def handle_KeywordCall(  # noqa: N802
         self,
         document: TextDocument,
         range: Range,
@@ -215,9 +236,9 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
             return None
 
         arguments = keyword_call.get_tokens(RobotToken.ARGUMENT)
-        return await self._handle_keywordcall_fixture_template(keyword_token, arguments, namespace, config)
+        return self._handle_keywordcall_fixture_template(keyword_token, arguments, namespace, config)
 
-    async def handle_Fixture(  # noqa: N802
+    def handle_Fixture(  # noqa: N802
         self,
         document: TextDocument,
         range: Range,
@@ -235,9 +256,9 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
             return None
 
         arguments = fixture.get_tokens(RobotToken.ARGUMENT)
-        return await self._handle_keywordcall_fixture_template(keyword_token, arguments, namespace, config)
+        return self._handle_keywordcall_fixture_template(keyword_token, arguments, namespace, config)
 
-    async def handle_TestTemplate(  # noqa: N802
+    def handle_TestTemplate(  # noqa: N802
         self,
         document: TextDocument,
         range: Range,
@@ -254,9 +275,9 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
         if keyword_token is None or not keyword_token.value:
             return None
 
-        return await self._handle_keywordcall_fixture_template(keyword_token, [], namespace, config)
+        return self._handle_keywordcall_fixture_template(keyword_token, [], namespace, config)
 
-    async def handle_Template(  # noqa: N802
+    def handle_Template(  # noqa: N802
         self,
         document: TextDocument,
         range: Range,
@@ -273,9 +294,9 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
         if keyword_token is None or not keyword_token.value:
             return None
 
-        return await self._handle_keywordcall_fixture_template(keyword_token, [], namespace, config)
+        return self._handle_keywordcall_fixture_template(keyword_token, [], namespace, config)
 
-    async def handle_LibraryImport(  # noqa: N802
+    def handle_LibraryImport(  # noqa: N802
         self,
         document: TextDocument,
         range: Range,
@@ -294,33 +315,32 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
 
         lib_doc: Optional[LibraryDoc] = None
         try:
-            namespace = await self.parent.documents_cache.get_namespace(document)
+            namespace = self.parent.documents_cache.get_namespace(document)
 
-            lib_doc = await namespace.get_imported_library_libdoc(
-                library_node.name, library_node.args, library_node.alias
-            )
+            lib_doc = namespace.get_imported_library_libdoc(library_node.name, library_node.args, library_node.alias)
 
             if lib_doc is None or lib_doc.errors:
-                lib_doc = await namespace.imports_manager.get_libdoc_for_library_import(
+                lib_doc = namespace.imports_manager.get_libdoc_for_library_import(
                     str(library_node.name),
                     (),
                     str(document.uri.to_path().parent),
-                    variables=await namespace.get_resolvable_variables(),
+                    variables=namespace.get_resolvable_variables(),
                 )
 
-        except (asyncio.CancelledError, SystemExit, KeyboardInterrupt):
+        except (SystemExit, KeyboardInterrupt):
             raise
-        except BaseException:
+        except BaseException as e:
+            self._logger.exception(e)
             return None
 
         arguments = library_node.get_tokens(RobotToken.ARGUMENT)
 
         for kw_doc in lib_doc.inits:
-            return await self._get_inlay_hint(None, kw_doc, arguments, namespace, config)
+            return self._get_inlay_hint(None, kw_doc, arguments, namespace, config)
 
         return None
 
-    async def handle_VariablesImport(  # noqa: N802
+    def handle_VariablesImport(  # noqa: N802
         self,
         document: TextDocument,
         range: Range,
@@ -339,29 +359,27 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
 
         lib_doc: Optional[LibraryDoc] = None
         try:
-            namespace = await self.parent.documents_cache.get_namespace(document)
+            namespace = self.parent.documents_cache.get_namespace(document)
 
-            lib_doc = await namespace.get_imported_variables_libdoc(
-                library_node.name,
-                library_node.args,
-            )
+            lib_doc = namespace.get_imported_variables_libdoc(library_node.name, library_node.args)
 
             if lib_doc is None or lib_doc.errors:
-                lib_doc = await namespace.imports_manager.get_libdoc_for_variables_import(
+                lib_doc = namespace.imports_manager.get_libdoc_for_variables_import(
                     str(library_node.name),
                     (),
                     str(document.uri.to_path().parent),
-                    variables=await namespace.get_resolvable_variables(),
+                    variables=namespace.get_resolvable_variables(),
                 )
 
-        except (asyncio.CancelledError, SystemExit, KeyboardInterrupt):
+        except (SystemExit, KeyboardInterrupt):
             raise
-        except BaseException:
+        except BaseException as e:
+            self._logger.exception(e)
             return None
 
         arguments = library_node.get_tokens(RobotToken.ARGUMENT)
 
         for kw_doc in lib_doc.inits:
-            return await self._get_inlay_hint(None, kw_doc, arguments, namespace, config)
+            return self._get_inlay_hint(None, kw_doc, arguments, namespace, config)
 
         return None
